.. laymon documentation master file, created by
   sphinx-quickstart on Sat Aug 15 15:42:59 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. _topics-index:

Welcome to PyLaymon |version| Documentation
======================================================================

PyLaymon or laymon is a tool for monitoring and visualizing feature maps for a neural network.
Currently, the PyLaymon is limited to the pytorch framework.

.. toctree::
    :maxdepth: 2
    :caption: Contents

    about
    installation
    usage
    contributing
    authors

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
